@@ -45,6 +45,7 @@ public:
         gboolean icon_title{false};
         gboolean keep{false};
         gboolean no_argb_visual{false};
+        gboolean no_bold{false};
         gboolean no_bold_is_bright{false};
         gboolean no_builtin_dingus{false};
         gboolean no_context_menu{false};
@@ -55,6 +56,7 @@ public:
         gboolean no_shell{false};
         gboolean object_notifications{false};
         gboolean reverse{false};
+        gboolean test_mode{false};
         gboolean use_gregex{false};
         gboolean version{false};
         gboolean whole_window_transparent{false};
@@ -352,7 +354,7 @@ public:
                         { "debug", 'd', 0,G_OPTION_ARG_NONE, &debug,
                           "Enable various debugging checks", nullptr },
                         { "encoding", 0, 0, G_OPTION_ARG_STRING, &encoding,
-                          "Specify the terminal encoding to use", nullptr },
+                          "Specify the terminal encoding to use", "ENCODING" },
                         { "env", 0, 0, G_OPTION_ARG_FILENAME_ARRAY, &environment,
                           "Add environment variable to the child\'s environment", "VAR=VALUE" },
                         { "extra-margin", 0, 0, G_OPTION_ARG_INT, &extra_margin,
@@ -375,6 +377,8 @@ public:
                           "Live on after the command exits", nullptr },
                         { "no-argb-visual", 0, 0, G_OPTION_ARG_NONE, &no_argb_visual,
                           "Don't use an ARGB visual", nullptr },
+                        { "no-bold", 0, 0, G_OPTION_ARG_NONE, &no_bold,
+                          "Disable bold", nullptr },
                         { "no-bold-is-bright", 'B', 0, G_OPTION_ARG_NONE, &no_bold_is_bright,
                           "Bold does not brightens colors", nullptr },
                         { "no-builtin-dingus", 0, 0, G_OPTION_ARG_NONE, &no_builtin_dingus,
@@ -430,7 +434,10 @@ public:
                           &dummy_bool, nullptr, nullptr },
                         { "shell", 'S', G_OPTION_FLAG_REVERSE | G_OPTION_FLAG_HIDDEN,
                           G_OPTION_ARG_NONE, &no_shell, nullptr, nullptr },
-
+#ifdef VTE_DEBUG
+                        { "test-mode", 0, 0, G_OPTION_ARG_NONE, &test_mode,
+                          "Enable test mode", nullptr },
+#endif
                         { nullptr }
                 };
 
@@ -1825,6 +1832,7 @@ vteapp_window_constructed(GObject *object)
 
         vte_terminal_set_allow_hyperlink(window->terminal, !options.no_hyperlink);
         vte_terminal_set_audible_bell(window->terminal, options.audible_bell);
+        vte_terminal_set_allow_bold(window->terminal, !options.no_bold);
         vte_terminal_set_bold_is_bright(window->terminal, !options.no_bold_is_bright);
         vte_terminal_set_cell_height_scale(window->terminal, options.cell_height_scale);
         vte_terminal_set_cell_width_scale(window->terminal, options.cell_width_scale);
@@ -2101,6 +2109,14 @@ main(int argc,
 
        if (options.debug)
                gdk_window_set_debug_updates(true);
+#ifdef VTE_DEBUG
+       if (options.test_mode) {
+               g_setenv("VTE_TEST", "1", true);
+               options.allow_window_ops = true;
+       } else {
+               g_unsetenv("VTE_TEST");
+       }
+#endif
 
        auto app = vteapp_application_new();
        auto rv = g_application_run(app, 0, nullptr);
