@@ -46,6 +46,12 @@ void vte_terminal_match_set_cursor(VteTerminal *terminal,
                                    int tag,
                                    GdkCursor *cursor) _VTE_GNUC_NONNULL(1);
 
+_VTE_DEPRECATED
+_VTE_PUBLIC
+void vte_terminal_match_set_cursor_type(VteTerminal *terminal,
+					int tag,
+                                        GdkCursorType cursor_type) _VTE_GNUC_NONNULL(1);
+
 _VTE_DEPRECATED
 _VTE_PUBLIC
 char *vte_terminal_match_check(VteTerminal *terminal,
@@ -89,6 +95,26 @@ _VTE_DEPRECATED
 _VTE_PUBLIC
 void vte_pty_close (VtePty *pty) _VTE_GNUC_NONNULL(1);
 
+_VTE_DEPRECATED
+_VTE_PUBLIC
+void vte_terminal_copy_clipboard(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
+
+_VTE_DEPRECATED
+_VTE_PUBLIC
+void vte_terminal_get_geometry_hints(VteTerminal *terminal,
+                                     GdkGeometry *hints,
+                                     int min_rows,
+                                     int min_columns) _VTE_GNUC_NONNULL(1) _VTE_GNUC_NONNULL(2);
+
+_VTE_DEPRECATED
+_VTE_PUBLIC
+void vte_terminal_set_geometry_hints_for_window(VteTerminal *terminal,
+                                                GtkWindow *window) _VTE_GNUC_NONNULL(1) _VTE_GNUC_NONNULL(2);
+
+_VTE_DEPRECATED
+_VTE_PUBLIC
+const char *vte_terminal_get_icon_title(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
+
 G_END_DECLS
 
 #undef _VTE_DEPRECATED
