@@ -390,10 +390,6 @@ int vte_terminal_match_add_regex(VteTerminal *terminal,
                                  guint32 flags) _VTE_GNUC_NONNULL(1) _VTE_GNUC_NONNULL(2);
 /* Set the cursor to be used when the pointer is over a given match. */
 _VTE_PUBLIC
-void vte_terminal_match_set_cursor_type(VteTerminal *terminal,
-					int tag,
-                                        GdkCursorType cursor_type) _VTE_GNUC_NONNULL(1);
-_VTE_PUBLIC
 void vte_terminal_match_set_cursor_name(VteTerminal *terminal,
 					int tag,
                                         const char *cursor_name) _VTE_GNUC_NONNULL(1) _VTE_GNUC_NONNULL(3);
@@ -468,8 +464,6 @@ glong vte_terminal_get_column_count(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
 _VTE_PUBLIC
 const char *vte_terminal_get_window_title(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
 _VTE_PUBLIC
-const char *vte_terminal_get_icon_title(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
-_VTE_PUBLIC
 const char *vte_terminal_get_current_directory_uri(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
 _VTE_PUBLIC
 const char *vte_terminal_get_current_file_uri(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
@@ -483,8 +477,8 @@ gboolean vte_terminal_get_input_enabled (VteTerminal *terminal) _VTE_GNUC_NONNUL
 
 /* rarely useful functions */
 _VTE_PUBLIC
-void vte_terminal_set_background_operator(VteTerminal* terminal,
-                                          cairo_operator_t op) _VTE_GNUC_NONNULL(1);
+void vte_terminal_set_clear_background(VteTerminal* terminal,
+                                       gboolean setting) _VTE_GNUC_NONNULL(1);
 
 /* Writing contents out */
 _VTE_PUBLIC
